@@ -1,5 +1,8 @@
 #!/bin/sh
-#  canonical test suite for fourfit
+#
+# $Id: chk_aedit.sh 330 2011-06-10 13:32:10Z gbc $
+#
+# canonical test suite for aedit
 #
 
 verb=false
@@ -17,7 +20,7 @@ rm -f alist.out
 $verb && echo \
 alist '??.?.?.'$time && ls -1 ??.?.?.$time
 alist ??.?.?.$time 2>/dev/null 1>&2 || {
-    echo run chk_ffb_2843.sh first
+    echo run chk_baselines.sh first
     exit 1
 }
 
