@@ -89,9 +89,15 @@ init_tokens ()
     tokenize (PC_FREQ_,     "pc_freqs"  , CHAN_PARAM)
     tokenize (USE_SAMPLES_, "use_samples",INT_PARAM)
     tokenize (PASSBAND_,    "passband",   TWO_FLOAT_PARAM)
+    tokenize (GEN_CF_RECORD_,"gen_cf_record", INT_PARAM)
+    tokenize (NOTCHES_,     "notches",    VECTOR_FLOAT_PARAM)
     tokenize (T_COHERE_,    "t_cohere",   FLOAT_PARAM)
     tokenize (IONOSPHERE_,  "ionosphere", FLOAT_PARAM)
     tokenize (DELAY_OFFS_,  "delay_offs", CHAN_PARAM)
+    tokenize (DELAY_OFFS_L_,"delay_offs_l",CHAN_PARAM)
+    tokenize (DELAY_OFFS_R_,"delay_offs_r",CHAN_PARAM)
+    tokenize (DELAY_OFFS_X_,"delay_offs_x",CHAN_PARAM)
+    tokenize (DELAY_OFFS_Y_,"delay_offs_y",CHAN_PARAM)
     tokenize (DC_BLOCK_,    "dc_block",   INT_PARAM)
     tokenize (SAMPLERS_,    "samplers",   VECTOR_STRING_PARAM)
     tokenize (OPTIMIZE_CLOSURE_, "optimize_closure", INT_PARAM)
@@ -99,6 +105,10 @@ init_tokens ()
     tokenize (PC_PHASE_R_,  "pc_phases_r",CHAN_PARAM)
     tokenize (PC_PHASE_X_,  "pc_phases_x",CHAN_PARAM)
     tokenize (PC_PHASE_Y_,  "pc_phases_y",CHAN_PARAM)
+    tokenize (PC_PHASE_OFFSET_L_,  "pc_phase_offset_l",FLOAT_PARAM)
+    tokenize (PC_PHASE_OFFSET_R_,  "pc_phase_offset_r",FLOAT_PARAM)
+    tokenize (PC_PHASE_OFFSET_X_,  "pc_phase_offset_x",FLOAT_PARAM)
+    tokenize (PC_PHASE_OFFSET_Y_,  "pc_phase_offset_y",FLOAT_PARAM)
     tokenize (ION_WIN_,     "ion_win",    TWO_FLOAT_PARAM)
     tokenize (ION_NPTS_,    "ion_npts",   INT_PARAM)
     tokenize (INTERPOLATOR_,"interpolator",INT_PARAM)
@@ -122,5 +132,6 @@ init_tokens ()
     tokenize (SAMPLER_DELAY_R_,"sampler_delay_r", VECTOR_FLOAT_PARAM)
     tokenize (SAMPLER_DELAY_X_,"sampler_delay_x", VECTOR_FLOAT_PARAM)
     tokenize (SAMPLER_DELAY_Y_,"sampler_delay_y", VECTOR_FLOAT_PARAM)
+    tokenize (ION_SMOOTH_,  "ion_smooth",   INT_PARAM)
+    tokenize (EST_PC_MANUAL_, "est_pc_manual", INT_PARAM)
     }
-
